@@ -1,4 +1,4 @@
-## ----setup, include=FALSE------------------------------------------------
+## ----setup, include=FALSE-----------------------------------------------------
 library(knitr)
 library(dplyr)
 library(simglm)
@@ -7,7 +7,7 @@ knit_print.data.frame = function(x, ...) {
   asis_output(res)
 }
 
-## ----fixed_sim-----------------------------------------------------------
+## ----fixed_sim----------------------------------------------------------------
 library(simglm)
 
 set.seed(321) 
@@ -28,7 +28,7 @@ sim_arguments <- list(
 fixed_data <- simulate_fixed(data = NULL, sim_arguments)
 head(fixed_data, n = 20)
 
-## ----time_var------------------------------------------------------------
+## ----time_var-----------------------------------------------------------------
 set.seed(321) 
 
 # To-DO: Add knot variable and debug
@@ -48,7 +48,7 @@ sim_arguments <- list(
 fixed_data <- simulate_fixed(data = NULL, sim_arguments)
 head(fixed_data, n = 20)
 
-## ----rbeta---------------------------------------------------------------
+## ----rbeta--------------------------------------------------------------------
 set.seed(321) 
 
 sim_arguments <- list(
@@ -67,14 +67,14 @@ sim_arguments <- list(
 fixed_data <- simulate_fixed(data = NULL, sim_arguments)
 head(fixed_data, n = 20)
 
-## ----dist_beta-----------------------------------------------------------
+## ----dist_beta----------------------------------------------------------------
 library(ggplot2)
 
 ggplot(fixed_data, aes(x = weight)) + 
   geom_density() + 
   theme_bw()
 
-## ----random_error--------------------------------------------------------
+## ----random_error-------------------------------------------------------------
 set.seed(321) 
 
 sim_arguments <- list(
@@ -91,7 +91,7 @@ sim_arguments <- list(
 error_data <- simulate_error(data = NULL, sim_arguments)
 head(error_data, n = 20)
 
-## ----random_error_t------------------------------------------------------
+## ----random_error_t-----------------------------------------------------------
 set.seed(321) 
 
 sim_arguments <- list(
@@ -109,7 +109,7 @@ sim_arguments <- list(
 error_data <- simulate_error(data = NULL, sim_arguments)
 head(error_data, n = 20)
 
-## ----re_10---------------------------------------------------------------
+## ----re_10--------------------------------------------------------------------
 set.seed(321) 
 
 sim_arguments <- list(
@@ -127,7 +127,7 @@ sim_arguments <- list(
 error_data <- simulate_error(data = NULL, sim_arguments)
 var(error_data$error)
 
-## ----re_10_ts------------------------------------------------------------
+## ----re_10_ts-----------------------------------------------------------------
 set.seed(321) 
 
 sim_arguments <- list(
@@ -145,7 +145,7 @@ sim_arguments <- list(
 error_data <- simulate_error(data = NULL, sim_arguments)
 var(error_data$error)
 
-## ----re_10_specify-------------------------------------------------------
+## ----re_10_specify------------------------------------------------------------
 set.seed(321) 
 
 sim_arguments <- list(
@@ -163,7 +163,7 @@ sim_arguments <- list(
 error_data <- simulate_error(data = NULL, sim_arguments)
 var(error_data$error)
 
-## ----heterogeneity-------------------------------------------------------
+## ----heterogeneity------------------------------------------------------------
 simulation_arguments <- list(
   formula = y ~ 1 + group,
   fixed = list(group = list(var_type = 'factor', 
@@ -179,13 +179,13 @@ hetero_data <- simulate_fixed(data = NULL, simulation_arguments) %>%
   simulate_error(simulation_arguments) %>%
   simulate_heterogeneity(simulation_arguments)
 
-## ----heterogeneity-var---------------------------------------------------
+## ----heterogeneity-var--------------------------------------------------------
 hetero_data %>% 
   group_by(group) %>% 
   summarise(var_error = var(error), 
             var_o_error = var(orig_error))
 
-## ----random_args---------------------------------------------------------
+## ----random_args--------------------------------------------------------------
 set.seed(321) 
 
 sim_arguments <- list(
@@ -204,7 +204,7 @@ sim_arguments <- list(
 random_data <- simulate_randomeffect(data = NULL, sim_arguments)
 head(random_data, n = 20)
 
-## ----cross-class---------------------------------------------------------
+## ----cross-class--------------------------------------------------------------
 set.seed(321) 
 
 sim_arguments <- list(
@@ -227,7 +227,7 @@ sim_arguments <- list(
 random_data <- simulate_randomeffect(data = NULL, sim_arguments)
 head(random_data, n = 20)
 
-## ----missing_random------------------------------------------------------
+## ----missing_random-----------------------------------------------------------
 set.seed(321) 
 
 sim_arguments <- list(
@@ -255,10 +255,10 @@ data_w_missing <- sim_arguments %>%
 
 head(data_w_missing, n = 10)
 
-## ----amount_missing------------------------------------------------------
+## ----amount_missing-----------------------------------------------------------
 prop.table(table(is.na(data_w_missing$y_missing)))
 
-## ----missing_mar---------------------------------------------------------
+## ----missing_mar--------------------------------------------------------------
 set.seed(321) 
 
 sim_arguments <- list(
@@ -288,10 +288,10 @@ data_w_missing <- sim_arguments %>%
 
 head(data_w_missing, n = 10)
 
-## ----amount_missing_mar--------------------------------------------------
+## ----amount_missing_mar-------------------------------------------------------
 prop.table(table(is.na(data_w_missing$y_missing)))
 
-## ----missing_dropout-----------------------------------------------------
+## ----missing_dropout----------------------------------------------------------
 set.seed(321) 
 
 sim_arguments <- list(
@@ -319,13 +319,13 @@ data_w_missing <- sim_arguments %>%
 
 head(data_w_missing, n = 10)
 
-## ----amount_missing_dropout----------------------------------------------
+## ----amount_missing_dropout---------------------------------------------------
 prop.table(table(is.na(data_w_missing$y_missing)))
 
-## ----missing_by_time-----------------------------------------------------
+## ----missing_by_time----------------------------------------------------------
 prop.table(table(is.na(data_w_missing$y_missing), data_w_missing$time))
 
-## ----missing_dropout_spec------------------------------------------------
+## ----missing_dropout_spec-----------------------------------------------------
 set.seed(321) 
 
 sim_arguments <- list(
@@ -355,13 +355,13 @@ data_w_missing <- sim_arguments %>%
 
 head(data_w_missing, n = 10)
 
-## ----amount_missing_dropout_spec-----------------------------------------
+## ----amount_missing_dropout_spec----------------------------------------------
 prop.table(table(is.na(data_w_missing$y_missing)))
 
-## ----missing_by_time_dropout_spec----------------------------------------
+## ----missing_by_time_dropout_spec---------------------------------------------
 prop.table(table(is.na(data_w_missing$y_missing), data_w_missing$time))
 
-## ----binomial_logit------------------------------------------------------
+## ----binomial_logit-----------------------------------------------------------
 set.seed(321) 
 
 sim_arguments <- list(
@@ -384,7 +384,7 @@ simulate_fixed(data = NULL, sim_arguments) %>%
   generate_response(sim_arguments) %>%
   model_fit(sim_arguments) %>% .$family
 
-## ----binomial_probit-----------------------------------------------------
+## ----binomial_probit----------------------------------------------------------
 set.seed(321) 
 
 sim_arguments <- list(
@@ -407,7 +407,7 @@ simulate_fixed(data = NULL, sim_arguments) %>%
   generate_response(sim_arguments) %>%
   model_fit(sim_arguments) %>% .$family
 
-## ----gee-----------------------------------------------------------------
+## ----gee----------------------------------------------------------------------
 set.seed(321) 
 
 # To-DO: Add knot variable and debug
@@ -443,9 +443,9 @@ simulate_fixed(data = NULL, sim_arguments) %>%
   model_fit(sim_arguments) %>%
   extract_coefficients()
 
-## ----vary_simulation-----------------------------------------------------
-library(future.apply)
-plan(multiprocess)
+## ----vary_simulation----------------------------------------------------------
+library(future)
+plan(sequential)
 
 sim_arguments <- list(
   formula =  resp_var ~ 1 + time + factor(trt) + time:factor(trt) + 
